@@ -5,4 +5,4 @@ package bertybridge
 
 import "berty.tech/berty/v2/go/pkg/tempdir"
 
-func (c *Config) SetAndroidCacheDir(path string) { tempdir.SetAndroidCacheDir(path) }
+func (c *BridgeConfig) SetAndroidCacheDir(path string) { tempdir.SetAndroidCacheDir(path) }
