@@ -51,21 +51,11 @@ func verifyRunningLeakDetection(t *testing.T) {
 		goleak.IgnoreTopFunction("github.com/jbenet/goprocess/context.CloseAfterContext.func1"),                              // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),                                  // FIXME - upstream code - is used in many code of libp2p + go-ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).run"),                                         // this goroutine has run always without stop
-		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).runActive"),                                   // this goroutine has run always without stop
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-autonat.(*AmbientAutoNAT).background"),                         // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-autonat.(*autoNATService).background"),                         // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-circuit.(*RelayListener).Accept"),                              // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-connmgr.(*BasicConnMgr).background"),                           // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-connmgr.(*decayer).process"),                                   // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-noise.newSecureSession"),                                       // upstream issue
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-peerstore/pstoremem.(*memoryAddrBook).background"),             // upstream issue, no store close in upstream code
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-quic-transport.(*reuse).runGarbageCollector"),                  // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 30 seconds
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-quic-transport.(*transport).Dial.func1"),                       // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-swarm.(*DialBackoff).background"),                              // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-swarm.(*Swarm).dialAddrs"),                                     // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-swarm.(*activeDial).wait"),                                     // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-transport-upgrader.(*Upgrader).setupMuxer"),                    // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-transport-upgrader.(*listener).Accept"),                        // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).runActive"),                                   // this goroutine has run always without stop                                       // upstream issue
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/host/peerstore/pstoremem.(*memoryAddrBook).background"),    // upstream issue, no store close in upstream code
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/swarm.(*DialBackoff).background"),                      // the cleanup take too much time, should be managed by ipfs
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/upgrader.(*Upgrader).setupMuxer"),                      // the closing routine has big timeout
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/upgrader.(*listener).Accept"),                          // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("berty.tech/berty/v2/go/internal/ipfsutil.(*mdnsService).startResolver.func1"),              // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 10 seconds
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/host/basic.(*BasicHost).background"),                       // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/host/basic.(*BasicHost).dialPeer"),                         // sometimes happening on CI, need more investigation
@@ -75,12 +65,6 @@ func verifyRunningLeakDetection(t *testing.T) {
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/protocol/identify.(*IDService).loop.func1"),                // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/protocol/identify.(*ObservedAddrManager).worker"),          // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/protocol/identify.(*peerHandler).loop"),                    // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-mplex.(*Multiplex).Accept"),                                           // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-mplex.(*Multiplex).handleOutgoing"),                                   // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-mplex.(*Stream).waitForData"),                                         // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/libp2p/go-nat.DiscoverGateway"),                                                 // upstream code - DiscoverGateway() using context.Background() with timeout is 10s
-		goleak.IgnoreTopFunction("github.com/libp2p/go-nat.DiscoverNATs.func1"),                                              // upstream code - DiscoverGateway() using context.Background() with timeout is 10s
-		goleak.IgnoreTopFunction("github.com/libp2p/go-nat.discoverNATPMP.func1"),                                            // upstream code
 		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go.(*baseServer).accept"),                                   // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go.(*baseServer).run"),                                      // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go.(*client).dial"),                                         // the closing routine has big timeout
@@ -91,15 +75,11 @@ func verifyRunningLeakDetection(t *testing.T) {
 		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go.(*session).run"),                                         // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go/internal/handshake.(*cryptoSetup).ReadHandshakeMessage"), // the closing routine has big timeout
 		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go/internal/handshake.(*cryptoSetup).RunHandshake"),         // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-quic-transport.(*reuse).gc"),                                   // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/whyrusleeping/mdns.(*client).query"),                                            // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/discovery/mdns_legacy.(*mdnsService).startResolver.func1"), // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/discovery/mdns_legacy.(*mdnsService).startResolver.func1"), // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/discovery/mdns.(*mdnsService).startResolver.func1"),        // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/zeroconf/v2.(*client).mainloop"),                                         // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/zeroconf/v2.(*client).periodicQuery"),                                    // the closing routine has big timeout, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/ipfs/go-ipfs/core/bootstrap.bootstrapConnect.func1 "),                           // the closing routine has big timeout, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-nat.(*NAT).refreshMappings"),                                   // the closing routine has big timeout, should be managed by ipfs
+		goleak.IgnoreTopFunction("github.com/ipfs/kubo/core/bootstrap.bootstrapConnect.func1 "),                              // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),                                              // called by init() in berty/go/internal/grpcutil/server.go
 		goleak.IgnoreTopFunction("go.uber.org/fx.withTimeout"),                                                               // sometimes happening on CI, need more investigation
 		goleak.IgnoreTopFunction("internal/poll.runtime_pollWait"),                                                           // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 10 seconds
@@ -111,8 +91,7 @@ func verifyRunningLeakDetection(t *testing.T) {
 
 func Example_flags() {
 	// init manager
-	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	if err != nil {
 		panic(err)
 	}
@@ -138,7 +117,7 @@ func Example_flags() {
 func Example_noflags() {
 	// init manager
 	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	if err != nil {
 		panic(err)
 	}
@@ -181,14 +160,12 @@ func Example_noflags() {
 
 func TestTwoConcurrentManagers(t *testing.T) {
 	var man1, man2 *initutil.Manager
-	var ctx1, ctx2 context.Context
 
 	// FIXME: automatically find an available port
 
 	// init man 1
 	{
-		ctx1 = context.Background()
-		manager, err := initutil.New(ctx1, nil)
+		manager, err := initutil.New(nil)
 		require.NoError(t, err)
 		require.NotNil(t, manager)
 		defer manager.Close(nil)
@@ -203,8 +180,7 @@ func TestTwoConcurrentManagers(t *testing.T) {
 
 	// init man 2
 	{
-		ctx2 = context.Background()
-		manager, err := initutil.New(ctx2, nil)
+		manager, err := initutil.New(nil)
 		require.NoError(t, err)
 		require.NotNil(t, manager)
 		defer manager.Close(nil)
@@ -233,42 +209,21 @@ func TestTwoConcurrentManagers(t *testing.T) {
 		require.NoError(t, err)
 		require.NotNil(t, client)
 
-		ret, err := client.InstanceGetConfiguration(ctx2, &protocoltypes.InstanceGetConfiguration_Request{})
+		ctx := context.Background()
+		ret, err := client.InstanceGetConfiguration(ctx, &protocoltypes.InstanceGetConfiguration_Request{})
 		require.NoError(t, err)
 		require.NotNil(t, ret.AccountPK)
 	}
 }
 
-func TestCloseByContext(t *testing.T) {
-	defer verifyRunningLeakDetection(t)
-
-	ctx, cancel := context.WithCancel(context.Background())
-	defer cancel()
-
-	manager, err := initutil.New(ctx, nil)
-	require.NoError(t, err)
-	require.NotNil(t, manager)
-
-	// configure flags
-	fs := flag.NewFlagSet("test", flag.ExitOnError)
-	manager.SetupLoggingFlags(fs)
-	manager.SetupLocalProtocolServerFlags(fs)
-	manager.SetupEmptyGRPCListenersFlags(fs)
-	fs.Parse([]string{"-store.inmem", "-node.listeners=/ip4/127.0.0.1/tcp/0/grpc", "-log.filters=", "-log.ring-filters="})
-
-	server, err := manager.GetLocalProtocolServer()
-	require.NoError(t, err)
-	require.NotNil(t, server)
-}
-
 func TestFlagsLeak(t *testing.T) {
 	// FIXME : should call defer verifySetupLeakDetection(t)
 	// but maybe because when run test with other tests, still have some goroutine of previous tests are not done
 	defer verifyRunningLeakDetection(t)
-	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	require.NoError(t, err)
 	require.NotNil(t, manager)
+	defer manager.Close(nil)
 
 	// configure flags
 	fs := flag.NewFlagSet("test", flag.ExitOnError)
@@ -281,7 +236,7 @@ func TestFlagsLeak(t *testing.T) {
 
 func TestLocalProtocolServerAndClient(t *testing.T) {
 	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	require.NoError(t, err)
 	require.NotNil(t, manager)
 	defer manager.Close(nil)
@@ -309,8 +264,7 @@ func TestLocalProtocolServerAndClient(t *testing.T) {
 
 func TestLocalProtocolServerLeak(t *testing.T) {
 	defer verifyRunningLeakDetection(t)
-	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	require.NoError(t, err)
 	require.NotNil(t, manager)
 	defer manager.Close(nil)
@@ -330,8 +284,7 @@ func TestLocalProtocolServerLeak(t *testing.T) {
 func TestCloseOnUninited(t *testing.T) {
 	defer verifyRunningLeakDetection(t)
 
-	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	require.NoError(t, err)
 	require.NotNil(t, manager)
 	manager.Close(nil)
@@ -340,8 +293,7 @@ func TestCloseOnUninited(t *testing.T) {
 func TestClosingTwice(t *testing.T) {
 	defer verifyRunningLeakDetection(t)
 
-	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	require.NoError(t, err)
 	require.NotNil(t, manager)
 
@@ -370,8 +322,7 @@ func TestCloseOpenClose(t *testing.T) {
 func TestRacyClose(t *testing.T) {
 	defer verifyRunningLeakDetection(t)
 
-	ctx := context.Background()
-	manager, err := initutil.New(ctx, nil)
+	manager, err := initutil.New(nil)
 	require.NoError(t, err)
 	require.NotNil(t, manager)
 
