@@ -1,20 +1,15 @@
 package ipfsutil
 
 import (
-	ipfs_core "github.com/ipfs/go-ipfs/core"
-	ipfs_coreapi "github.com/ipfs/go-ipfs/core/coreapi"
 	ipfs_interface "github.com/ipfs/interface-go-ipfs-core"
-	"github.com/libp2p/go-libp2p-core/connmgr"
-	ipfs_host "github.com/libp2p/go-libp2p-core/host"
-	peer "github.com/libp2p/go-libp2p-core/peer"
+	ipfs_core "github.com/ipfs/kubo/core"
+	ipfs_coreapi "github.com/ipfs/kubo/core/coreapi"
+	"github.com/libp2p/go-libp2p/core/connmgr"
+	ipfs_host "github.com/libp2p/go-libp2p/core/host"
 )
 
 type ConnMgr interface {
-	TagPeer(peer.ID, string, int)
-	UntagPeer(p peer.ID, tag string)
-	Protect(id peer.ID, tag string)
-	Unprotect(id peer.ID, tag string) (protected bool)
-	GetTagInfo(p peer.ID) *connmgr.TagInfo
+	connmgr.ConnManager
 }
 
 type ExtendedCoreAPI interface {
