@@ -3,34 +3,35 @@ package bertymessenger
 import (
 	"bufio"
 	"context"
-	"errors"
 	"fmt"
 	"io"
 	"io/ioutil"
 	"math"
+	mrand "math/rand"
 	"net"
-	"net/url"
 	"os"
 	"strings"
 	"time"
 
-	"github.com/cenkalti/backoff"
 	"github.com/gogo/protobuf/proto"
 	"github.com/grandcat/zeroconf"
 	ipfscid "github.com/ipfs/go-cid"
 	ctxio "github.com/jbenet/go-context/io"
+	backoff "github.com/libp2p/go-libp2p/p2p/discovery/backoff"
 	"go.uber.org/multierr"
 	"go.uber.org/zap"
+	"google.golang.org/grpc/codes"
+	"google.golang.org/grpc/status"
+	"moul.io/srand"
 
-	"berty.tech/berty/v2/go/internal/bertylinks"
 	"berty.tech/berty/v2/go/internal/discordlog"
 	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerutil"
-	"berty.tech/berty/v2/go/internal/streamutil"
 	"berty.tech/berty/v2/go/internal/sysutil"
 	"berty.tech/berty/v2/go/pkg/authtypes"
 	"berty.tech/berty/v2/go/pkg/banner"
+	"berty.tech/berty/v2/go/pkg/bertylinks"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
 	"berty.tech/berty/v2/go/pkg/protocoltypes"
@@ -397,24 +398,6 @@ func (svc *service) streamEverything(sub messengertypes.MessengerService_EventSt
 		}
 	}
 
-	// send medias
-	{
-		medias, err := svc.db.GetAllMedias()
-		if err != nil {
-			return err
-		}
-		svc.logger.Info("sending existing medias", zap.Int("count", len(medias)))
-		for _, media := range medias {
-			mu, err := proto.Marshal(&messengertypes.StreamEvent_MediaUpdated{Media: media})
-			if err != nil {
-				return err
-			}
-			if err := sub.Send(&messengertypes.EventStream_Reply{Event: &messengertypes.StreamEvent{Type: messengertypes.StreamEvent_TypeMediaUpdated, Payload: mu, IsNew: false}}); err != nil {
-				return err
-			}
-		}
-	}
-
 	return nil
 }
 
@@ -491,7 +474,7 @@ func (svc *service) streamShallow(sub messengertypes.MessengerService_EventStrea
 
 	// send interactions
 	if includeInteractionsAndMedias > 0 {
-		interactions, medias, err := svc.db.GetPaginatedInteractions(&messengertypes.PaginatedInteractionsOptions{Amount: includeInteractionsAndMedias})
+		interactions, err := svc.db.GetPaginatedInteractions(&messengertypes.PaginatedInteractionsOptions{Amount: includeInteractionsAndMedias})
 		if err != nil {
 			return err
 		}
@@ -505,17 +488,6 @@ func (svc *service) streamShallow(sub messengertypes.MessengerService_EventStrea
 				return err
 			}
 		}
-
-		svc.logger.Info("sending existing medias", zap.Int("count", len(medias)))
-		for _, media := range medias {
-			mu, err := proto.Marshal(&messengertypes.StreamEvent_MediaUpdated{Media: media})
-			if err != nil {
-				return err
-			}
-			if err := sub.Send(&messengertypes.EventStream_Reply{Event: &messengertypes.StreamEvent{Type: messengertypes.StreamEvent_TypeMediaUpdated, Payload: mu, IsNew: false}}); err != nil {
-				return err
-			}
-		}
 	}
 
 	return nil
@@ -652,7 +624,7 @@ func (svc *service) ConversationCreate(ctx context.Context, req *messengertypes.
 	// Try to put group name in group metadata
 	{
 		err := func() error {
-			am, err := messengertypes.AppMessage_TypeSetGroupInfo.MarshalPayload(0, "", nil, &messengertypes.AppMessage_SetGroupInfo{DisplayName: dn})
+			am, err := messengertypes.AppMessage_TypeSetGroupInfo.MarshalPayload(0, "", &messengertypes.AppMessage_SetGroupInfo{DisplayName: dn})
 			if err != nil {
 				return err
 			}
@@ -675,7 +647,7 @@ func (svc *service) ConversationCreate(ctx context.Context, req *messengertypes.
 	}
 
 	for _, contactPK := range req.GetContactsToInvite() {
-		am, err := messengertypes.AppMessage_TypeGroupInvitation.MarshalPayload(messengerutil.TimestampMs(time.Now()), "", nil, &messengertypes.AppMessage_GroupInvitation{Link: conv.GetLink()})
+		am, err := messengertypes.AppMessage_TypeGroupInvitation.MarshalPayload(messengerutil.TimestampMs(time.Now()), "", &messengertypes.AppMessage_GroupInvitation{Link: conv.GetLink()})
 		if err != nil {
 			return nil, err
 		}
@@ -789,15 +761,6 @@ func (svc *service) AccountUpdate(ctx context.Context, req *messengertypes.Accou
 	svc.handlerMutex.Lock()
 	defer svc.handlerMutex.Unlock()
 
-	avatarCID := req.GetAvatarCID()
-	if avatarCID != "" {
-		if err := messengerutil.EnsureValidBase64CID(avatarCID); err != nil {
-			err = fmt.Errorf("couldn't ensure the avatar cid is a valid ipfs cid: %s", err)
-			svc.logger.Error("AccountUpdate: bad avatar cid", zap.Error(err))
-			return nil, errcode.ErrInvalidInput.Wrap(err)
-		}
-	}
-
 	if err := svc.db.TX(ctx, func(tx *messengerdb.DBWrapper) error {
 		acc, err := tx.GetAccount()
 		if err != nil {
@@ -810,15 +773,12 @@ func (svc *service) AccountUpdate(ctx context.Context, req *messengertypes.Accou
 		if dn != "" && dn != acc.GetDisplayName() {
 			updated = true
 		}
-		if avatarCID != "" && avatarCID != acc.GetAvatarCID() {
-			updated = true
-		}
 
 		if !updated {
 			svc.logger.Debug("AccountUpdate: nothing to do")
 			return nil
 		}
-		svc.logger.Debug("AccountUpdate: updating account", logutil.PrivateString("display_name", dn), logutil.PrivateString("avatar_cid", avatarCID))
+		svc.logger.Debug("AccountUpdate: updating account", logutil.PrivateString("display_name", dn))
 
 		ret, err := svc.internalInstanceShareableBertyID(ctx, &messengertypes.InstanceShareableBertyID_Request{DisplayName: dn})
 		if err != nil {
@@ -826,7 +786,7 @@ func (svc *service) AccountUpdate(ctx context.Context, req *messengertypes.Accou
 			return err
 		}
 
-		acc, err = tx.UpdateAccount(acc.PublicKey, ret.GetWebURL(), dn, avatarCID)
+		acc, err = tx.UpdateAccount(acc.PublicKey, ret.GetWebURL(), dn)
 		if err != nil {
 			svc.logger.Error("AccountUpdate: updating account in db", zap.Error(err))
 			return err
@@ -980,34 +940,21 @@ func (svc *service) Interact(ctx context.Context, req *messengertypes.Interact_R
 	}
 	tyber.LogStep(ctx, svc.logger, "Unmarshaled payload", tyber.WithJSONDetail("AppMessagePayload", payload))
 
-	medias, err := svc.db.GetMedias(req.GetMediaCids())
-	if err != nil {
-		return nil, errcode.ErrDBRead.Wrap(err)
-	}
-
-	fp, err := req.GetType().MarshalPayload(messengerutil.TimestampMs(time.Now()), req.GetTargetCID(), medias, payload)
+	fp, err := req.GetType().MarshalPayload(messengerutil.TimestampMs(time.Now()), req.GetTargetCID(), payload)
 	if err != nil {
 		return nil, errcode.ErrInternal.Wrap(err)
 	}
 
-	cids := make([][]byte, len(req.GetMediaCids()))
-	for i, mediaCID := range req.GetMediaCids() {
-		cids[i], err = messengerutil.B64DecodeBytes(mediaCID)
-		if err != nil {
-			return nil, errcode.ErrDeserialization.Wrap(err)
-		}
-	}
-
 	var cidBytes []byte
 
 	if req.GetMetadata() {
-		reply, err := svc.protocolClient.AppMetadataSend(ctx, &protocoltypes.AppMetadataSend_Request{GroupPK: gpkb, Payload: fp, AttachmentCIDs: cids})
+		reply, err := svc.protocolClient.AppMetadataSend(ctx, &protocoltypes.AppMetadataSend_Request{GroupPK: gpkb, Payload: fp})
 		if err != nil {
 			return nil, errcode.ErrProtocolSend.Wrap(err)
 		}
 		cidBytes = reply.GetCID()
 	} else {
-		reply, err := svc.protocolClient.AppMessageSend(ctx, &protocoltypes.AppMessageSend_Request{GroupPK: gpkb, Payload: fp, AttachmentCIDs: cids})
+		reply, err := svc.protocolClient.AppMessageSend(ctx, &protocoltypes.AppMessageSend_Request{GroupPK: gpkb, Payload: fp})
 		if err != nil {
 			return nil, errcode.ErrProtocolSend.Wrap(err)
 		}
@@ -1090,6 +1037,11 @@ func (svc *service) ConversationOpen(ctx context.Context, req *messengertypes.Co
 
 	ret := messengertypes.ConversationOpen_Reply{}
 
+	if err := svc.monitorGroupPeersStatus(req.GroupPK); err != nil {
+		// only log an error here
+		svc.logger.Error("unable to monitor group peer status", zap.Error(err))
+	}
+
 	conv, updated, err := svc.db.SetConversationIsOpenStatus(req.GetGroupPK(), true)
 
 	if err != nil {
@@ -1105,6 +1057,119 @@ func (svc *service) ConversationOpen(ctx context.Context, req *messengertypes.Co
 	return &ret, nil
 }
 
+func (svc *service) monitorGroupPeersStatus(groupPK string) error {
+	svc.muCancelGroupStatus.Lock()
+	defer svc.muCancelGroupStatus.Unlock()
+
+	if _, found := svc.cancelGroupStatus[groupPK]; found {
+		// skip if already have a monitor group in progress
+		return fmt.Errorf("monitor peer status for group already running")
+	}
+
+	rawGroupPK, err := messengerutil.B64DecodeBytes(groupPK)
+	if err != nil {
+		svc.logger.Error("error while decoding groupPK", zap.Error(err))
+		return fmt.Errorf("error while decoding groupPK: %w", err)
+	}
+
+	subCtx, cancel := context.WithCancel(svc.ctx)
+	cs, err := svc.protocolClient.GroupDeviceStatus(subCtx, &protocoltypes.GroupDeviceStatus_Request{GroupPK: rawGroupPK})
+	if err != nil {
+		cancel()
+		return fmt.Errorf("unable to get group device status: %w", err)
+	}
+
+	svc.cancelGroupStatus[groupPK] = cancel
+
+	groupPeers := make(map[string]struct{})
+	go func() {
+		for {
+			statusEvent, err := cs.Recv()
+			switch {
+			case err == nil: // ok
+			case err == io.EOF, status.Code(err) != codes.Canceled: // shutdown gracefully
+				return
+			default:
+				svc.logger.Error("error while getting GroupDeviceStatus from protocol", zap.Error(err))
+				return
+			}
+
+			switch kind := statusEvent.Type; kind {
+			case protocoltypes.TypePeerConnected:
+				var connected protocoltypes.GroupDeviceStatus_Reply_PeerConnected
+				if err = connected.Unmarshal(statusEvent.Event); err != nil {
+					svc.logger.Error("unable to unmarshall", zap.Error(err))
+					continue
+				}
+
+				svc.muKnownPeers.Lock()
+				if status, ok := svc.knownPeers[connected.PeerID]; !ok || status != kind {
+					svc.knownPeers[connected.PeerID] = kind
+
+					var transport messengertypes.StreamEvent_PeerStatusConnected_Transport
+					if len(connected.Transports) > 0 {
+						switch connected.Transports[0] {
+						case protocoltypes.TptWAN:
+							transport = messengertypes.StreamEvent_PeerStatusConnected_WAN
+						case protocoltypes.TptLAN:
+							transport = messengertypes.StreamEvent_PeerStatusConnected_LAN
+						case protocoltypes.TptProximity:
+							transport = messengertypes.StreamEvent_PeerStatusConnected_Proximity
+						}
+					}
+
+					err = svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypePeerStatusConnected,
+						&messengertypes.StreamEvent_PeerStatusConnected{
+							PeerID:    connected.PeerID,
+							Transport: transport,
+						}, true)
+				}
+				svc.muKnownPeers.Unlock()
+
+				if _, ok := groupPeers[connected.PeerID]; !ok {
+					groupPeers[connected.PeerID] = struct{}{}
+					err = svc.dispatcher.StreamEvent(
+						messengertypes.StreamEvent_TypePeerStatusGroupAssociated,
+						&messengertypes.StreamEvent_PeerStatusGroupAssociated{
+							PeerID:   connected.PeerID,
+							DevicePK: messengerutil.B64EncodeBytes(connected.DevicePK),
+							GroupPK:  groupPK,
+						}, true)
+
+					if err != nil {
+						svc.logger.Error("unable to disaptch event event", zap.String("kind", statusEvent.Type.String()))
+						continue
+					}
+				}
+
+			case protocoltypes.TypePeerDisconnected:
+				var disconnected protocoltypes.GroupDeviceStatus_Reply_PeerDisconnected
+				if err = disconnected.Unmarshal(statusEvent.Event); err != nil {
+					svc.logger.Error("unable to unmarshall", zap.Error(err))
+					continue
+				}
+
+				svc.muKnownPeers.Lock()
+				if status, ok := svc.knownPeers[disconnected.PeerID]; !ok || status != kind {
+					svc.knownPeers[disconnected.PeerID] = kind
+					err = svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypePeerStatusDisconnected,
+						&messengertypes.StreamEvent_PeerStatusDisconnected{
+							PeerID: disconnected.PeerID,
+						}, true)
+				}
+				svc.muKnownPeers.Unlock()
+			}
+
+			if err != nil {
+				svc.logger.Error("unable to disaptch event event", zap.String("kind", statusEvent.Type.String()))
+				continue
+			}
+		}
+	}()
+
+	return nil
+}
+
 func (svc *service) ConversationClose(ctx context.Context, req *messengertypes.ConversationClose_Request) (*messengertypes.ConversationClose_Reply, error) {
 	// check input
 	if req.GroupPK == "" {
@@ -1121,6 +1186,14 @@ func (svc *service) ConversationClose(ctx context.Context, req *messengertypes.C
 		return &ret, nil
 	}
 
+	// stop monitoring peer status
+	svc.muCancelGroupStatus.Lock()
+	if cancel, found := svc.cancelGroupStatus[req.GroupPK]; found {
+		cancel()
+		delete(svc.cancelGroupStatus, req.GroupPK)
+	}
+	svc.muCancelGroupStatus.Unlock()
+
 	if err := svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypeConversationUpdated, &messengertypes.StreamEvent_ConversationUpdated{Conversation: conv}, false); err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
@@ -1197,20 +1270,6 @@ func (svc *service) BannerQuote(ctx context.Context, req *messengertypes.BannerQ
 	return &ret, nil
 }
 
-func (svc *service) SendReplyOptions(ctx context.Context, req *messengertypes.SendReplyOptions_Request) (*messengertypes.SendReplyOptions_Reply, error) {
-	payload, err := messengertypes.AppMessage_TypeReplyOptions.MarshalPayload(messengerutil.TimestampMs(time.Now()), "", nil, req.Options)
-	if err != nil {
-		return nil, err
-	}
-
-	_, err = svc.protocolClient.AppMessageSend(ctx, &protocoltypes.AppMessageSend_Request{
-		GroupPK: req.GroupPK,
-		Payload: payload,
-	})
-
-	return &messengertypes.SendReplyOptions_Reply{}, err
-}
-
 func (svc *service) ReplicationSetAutoEnable(ctx context.Context, req *messengertypes.ReplicationSetAutoEnable_Request) (*messengertypes.ReplicationSetAutoEnable_Reply, error) {
 	config, err := svc.protocolClient.InstanceGetConfiguration(svc.ctx, &protocoltypes.InstanceGetConfiguration_Request{})
 	if err != nil {
@@ -1291,131 +1350,12 @@ func (svc *service) InstanceExportData(_ *messengertypes.InstanceExportData_Requ
 	}
 }
 
-func (svc *service) MediaPrepare(srv messengertypes.MessengerService_MediaPrepareServer) (err error) {
-	ctx, _, endSection := tyber.Section(srv.Context(), svc.logger, "Preparing media")
-	defer func() { endSection(err, "") }()
-
-	// read header
-	header, err := srv.Recv()
-	if err != nil {
-		return errcode.ErrStreamHeaderRead.Wrap(err)
-	}
-	if len(header.GetBlock()) > 0 {
-		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("expected empty block, got %v bytes", len(header.GetBlock())))
-	}
-	if header.GetInfo() == nil {
-		return errcode.ErrInvalidInput.Wrap(errors.New("nil info"))
-	}
-
-	var file io.ReadCloser
-	if header.GetUri() != "" {
-		// open uri file
-		path := header.GetUri()
-		u, err := url.Parse(header.GetUri())
-		if err == nil && u.Scheme == "file" {
-			path = u.Path
-		}
-		file, err = os.Open(path)
-		if err != nil {
-			return errcode.ErrInvalidInput.Wrap(err)
-		}
-	} else {
-		// open requests reader
-		file = streamutil.FuncReader(func() ([]byte, error) {
-			req, err := srv.Recv()
-			return req.GetBlock(), err
-		}, svc.logger)
-	}
-	defer file.Close()
-
-	// upload media and get cid in return
-	cidBytes, err := svc.attachmentPrepare(ctx, file)
-	if err != nil {
-		return errcode.ErrAttachmentPrepare.Wrap(err)
-	}
-	cid := messengerutil.B64EncodeBytes(cidBytes)
-
-	svc.handlerMutex.Lock()
-	defer svc.handlerMutex.Unlock()
-
-	return svc.db.TX(ctx, func(tx *messengerdb.DBWrapper) error {
-		// add to db
-		media := *header.Info
-		media.CID = cid
-		media.State = messengertypes.Media_StatePrepared
-		added, err := tx.AddMedias([]*messengertypes.Media{&media})
-		if err != nil {
-			return errcode.ErrDBWrite.Wrap(err)
-		}
-
-		// dispatch event if new
-		if added[0] {
-			if err := svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypeMediaUpdated, &messengertypes.StreamEvent_MediaUpdated{Media: &media}, true); err != nil {
-				svc.logger.Error("unable to dispatch notification for media", logutil.PrivateString("cid", media.CID), zap.Error(err))
-			}
-		}
-
-		// reply
-		if err := srv.SendAndClose(&messengertypes.MediaPrepare_Reply{Cid: cid}); err != nil {
-			return errcode.ErrStreamSendAndClose.Wrap(err)
-		}
-
-		// success
-		return nil
-	})
-}
-
-func (svc *service) MediaRetrieve(req *messengertypes.MediaRetrieve_Request, srv messengertypes.MessengerService_MediaRetrieveServer) (err error) {
-	ctx, _, endSection := tyber.Section(srv.Context(), svc.logger, "Retrieving media")
-	defer func() { endSection(err, "") }()
-
-	var attachment *io.PipeReader
-	if err := func() error {
-		svc.handlerMutex.Lock()
-		defer svc.handlerMutex.Unlock()
-
-		// prepare header
-		medias, err := svc.db.GetMedias([]string{req.GetCid()})
-		if err != nil {
-			return errcode.ErrInvalidInput.Wrap(err)
-		}
-		if len(medias) == 0 {
-			return errcode.ErrInternal.Wrap(err)
-		}
-		media := medias[0]
-
-		// send header
-		if err := srv.Send(&messengertypes.MediaRetrieve_Reply{Info: media}); err != nil {
-			return errcode.ErrStreamHeaderWrite.Wrap(err)
-		}
-
-		// open download
-		if attachment, err = svc.attachmentRetrieve(ctx, req.GetCid()); err != nil {
-			return errcode.ErrAttachmentRetrieve.Wrap(err)
-		}
-		return nil
-	}(); err != nil {
-		return err
-	}
-	defer attachment.Close()
-
-	// stream to client
-	if err := streamutil.FuncSink(make([]byte, 64*1024), attachment, func(b []byte) error {
-		return srv.Send(&messengertypes.MediaRetrieve_Reply{Block: b})
-	}); err != nil {
-		return errcode.ErrStreamSink.Wrap(err)
-	}
-
-	// success
-	return nil
-}
-
 func (svc *service) ConversationLoad(ctx context.Context, request *messengertypes.ConversationLoad_Request) (*messengertypes.ConversationLoad_Reply, error) {
 	if request.Options.ConversationPK == "" && request.Options.RefCID == "" {
 		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("no conversation pk or ref cid specified"))
 	}
 
-	interactions, medias, err := svc.db.GetPaginatedInteractions(request.Options)
+	interactions, err := svc.db.GetPaginatedInteractions(request.Options)
 	if err != nil {
 		return nil, err
 	}
@@ -1425,20 +1365,9 @@ func (svc *service) ConversationLoad(ctx context.Context, request *messengertype
 	}
 
 	if !request.Options.NoBulk {
-		if medias == nil {
-			medias = []*messengertypes.Media{}
-		}
-		ais := make([]*messengertypes.Interaction, len(interactions))
-		for i, inte := range interactions {
-			if ais[i], err = svc.db.GetAugmentedInteraction(inte.CID); err != nil {
-				return nil, errcode.ErrDBRead.Wrap(err)
-			}
-		}
-
 		if err := svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypeConversationPartialLoad, &messengertypes.StreamEvent_ConversationPartialLoad{
 			ConversationPK: interactions[0].ConversationPublicKey,
-			Interactions:   ais,
-			Medias:         medias,
+			Interactions:   interactions,
 		}, false); err != nil {
 			svc.logger.Error("unable to bulk send conversation events", zap.Error(err))
 			return nil, errcode.ErrInternal.Wrap(err)
@@ -1450,13 +1379,6 @@ func (svc *service) ConversationLoad(ctx context.Context, request *messengertype
 				return nil, err
 			}
 		}
-
-		svc.logger.Info("sending found medias", zap.Int("count", len(medias)))
-		for _, media := range medias {
-			if err := svc.dispatcher.StreamEvent(messengertypes.StreamEvent_TypeMediaUpdated, &messengertypes.StreamEvent_MediaUpdated{Media: media}, false); err != nil {
-				return nil, err
-			}
-		}
 	}
 
 	return &messengertypes.ConversationLoad_Reply{}, nil
@@ -1541,22 +1463,6 @@ func (svc *service) AccountPushConfigure(ctx context.Context, request *messenger
 	return &messengertypes.AccountPushConfigure_Reply{}, nil
 }
 
-func (svc *service) MediaGetRelated(ctx context.Context, request *messengertypes.MediaGetRelated_Request) (*messengertypes.MediaGetRelated_Reply, error) {
-	media, err := svc.db.GetNextMedia(request.CID, messengerdb.NextMediaOpts{
-		FileNames: request.FileNames,
-		MimeTypes: request.MimeTypes,
-	})
-	if err != nil || media == nil {
-		if err != nil {
-			svc.logger.Error("unable to retrieve next audio message", zap.Error(err))
-		}
-
-		return &messengertypes.MediaGetRelated_Reply{End: true}, nil
-	}
-
-	return &messengertypes.MediaGetRelated_Reply{Media: media}, nil
-}
-
 func (svc *service) MessageSearch(ctx context.Context, request *messengertypes.MessageSearch_Request) (*messengertypes.MessageSearch_Reply, error) {
 	results, err := svc.db.InteractionsSearch(request.Query, &messengerdb.SearchOptions{
 		BeforeDate:     int(request.BeforeDate),
@@ -1638,8 +1544,12 @@ func (svc *service) TyberHostAttach(ctx context.Context, request *messengertypes
 		return nil, errcode.TODO.Wrap(fmt.Errorf("cannot attach to tyber without specified log path"))
 	}
 
-	backoff := backoff.NewExponentialBackOff()
-	backoff.MaxInterval = time.Minute
+	srand := mrand.New(mrand.NewSource(srand.MustSecure())) // nolint:gosec
+	backoffFactory := backoff.NewExponentialBackoff(time.Second, time.Minute*15,
+		backoff.FullJitter,
+		time.Second*5, 5.0, 0, srand)
+	backoff := backoffFactory()
+
 	var succeed bool
 
 	// can be stopped either by calling TyberHostAttach again, or when the svc.Close is called.
@@ -1683,7 +1593,7 @@ func (svc *service) TyberHostAttach(ctx context.Context, request *messengertypes
 				return
 			}
 
-			sleepDuration := backoff.NextBackOff()
+			sleepDuration := backoff.Delay()
 
 			svc.logger.Debug(
 				"tyber host attach",
@@ -1821,13 +1731,3 @@ func (svc *service) PushTokenSharedForConversation(request *messengertypes.PushT
 
 	return nil
 }
-
-func (svc *service) InteractionReactionsForEmoji(ctx context.Context, request *messengertypes.InteractionReactionsForEmoji_Request) (*messengertypes.InteractionReactionsForEmoji_Reply, error) {
-	reactions, err := svc.db.GetInteractionReactionsForEmoji(request.InteractionCID, request.Emoji)
-	if err != nil {
-		return nil, errcode.ErrDBRead.Wrap(err)
-	}
-	return &messengertypes.InteractionReactionsForEmoji_Reply{
-		Reactions: reactions,
-	}, nil
-}
