@@ -7,9 +7,9 @@ import (
 	"time"
 
 	"github.com/gogo/protobuf/proto"
-	"github.com/libp2p/go-libp2p-core/crypto"
-	"github.com/libp2p/go-libp2p-core/network"
-	peer "github.com/libp2p/go-libp2p-core/peer"
+	"github.com/libp2p/go-libp2p/core/crypto"
+	"github.com/libp2p/go-libp2p/core/network"
+	peer "github.com/libp2p/go-libp2p/core/peer"
 	"go.uber.org/multierr"
 	"go.uber.org/zap"
 
@@ -118,9 +118,9 @@ func (s *service) DebugInspectGroupStore(req *protocoltypes.DebugInspectGroupSto
 
 			if op, err := operation.ParseOperation(e); err != nil {
 				s.logger.Error("unable to parse operation", zap.Error(err))
-			} else if meta, event, _, err := openGroupEnvelope(cg.group, op.GetValue(), s.deviceKeystore); err != nil {
+			} else if meta, event, err := openGroupEnvelope(cg.group, op.GetValue()); err != nil {
 				s.logger.Error("unable to open group envelope", zap.Error(err))
-			} else if metaEvent, err := newGroupMetadataEventFromEntry(log, e, meta, event, cg.group, nil); err != nil {
+			} else if metaEvent, err := newGroupMetadataEventFromEntry(log, e, meta, event, cg.group); err != nil {
 				s.logger.Error("unable to get group metadata event from entry", zap.Error(err))
 			} else {
 				payload = metaEvent.Event
