@@ -8,7 +8,7 @@ import (
 	"sync"
 	"time"
 
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
 	"go.uber.org/zap"
 	"golang.org/x/crypto/nacl/box"
 
@@ -226,7 +226,6 @@ func activateGroupContext(ctx context.Context, gc *GroupContext, contact crypto.
 
 			wg.Done()
 		}()
-
 		gc.logger.Info(fmt.Sprintf("FillMessageKeysHolderUsingPreviousData took %s", time.Since(start)))
 
 		start = time.Now()
@@ -275,7 +274,7 @@ func ActivateGroupContext(ctx context.Context, gc *GroupContext, contact crypto.
 	return activateGroupContext(ctx, gc, contact, true)
 }
 
-func TagGroupContextPeers(ctx context.Context, gc *GroupContext, ipfsCoreAPI ipfsutil.ExtendedCoreAPI, weight int) {
+func TagGroupContextPeers(ctx context.Context, logger *zap.Logger, gc *GroupContext, ipfsCoreAPI ipfsutil.ExtendedCoreAPI, weight int) {
 	id := gc.Group().GroupIDAsString()
 
 	chSub1, err := gc.metadataStore.EventBus().Subscribe(new(stores.EventNewPeer))
@@ -305,7 +304,10 @@ func TagGroupContextPeers(ctx context.Context, gc *GroupContext, ipfsCoreAPI ipf
 			}
 
 			evt := e.(stores.EventNewPeer)
-			ipfsCoreAPI.ConnMgr().TagPeer(evt.Peer, fmt.Sprintf("grp_%s", id), weight)
+
+			tag := fmt.Sprintf("grp_%s", id)
+			logger.Debug("new peer of interest", logutil.PrivateStringer("peer", evt.Peer), zap.String("tag", tag), zap.Int("score", weight))
+			ipfsCoreAPI.ConnMgr().TagPeer(evt.Peer, tag, weight)
 		}
 	}()
 }
