@@ -4,7 +4,7 @@ import (
 	crand "crypto/rand"
 	"testing"
 
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
 	"github.com/stretchr/testify/require"
 
 	"berty.tech/berty/v2/go/internal/cryptoutil"
