@@ -11,8 +11,9 @@ import (
 	"github.com/ipfs/go-datastore"
 	ds_sync "github.com/ipfs/go-datastore/sync"
 	coreapi "github.com/ipfs/interface-go-ipfs-core"
-	"github.com/libp2p/go-eventbus"
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
+	peer "github.com/libp2p/go-libp2p/core/peer"
+	"github.com/libp2p/go-libp2p/p2p/host/eventbus"
 	"github.com/pkg/errors"
 	"go.uber.org/zap"
 
@@ -80,19 +81,33 @@ func (n *NewOrbitDBOptions) applyDefaults() {
 	if n.RotationInterval == nil {
 		n.RotationInterval = rendezvous.NewStaticRotationInterval()
 	}
+
+	if n.Logger == nil {
+		n.Logger = zap.NewNop()
+	}
+	n.Logger = n.Logger.Named("odb")
 }
 
+type (
+	GroupMap           = sync.Map
+	GroupContextMap    = sync.Map
+	GroupsSigPubKeyMap = sync.Map
+)
+
 type BertyOrbitDB struct {
 	baseorbitdb.BaseOrbitDB
-	rotationInterval *rendezvous.RotationInterval
-	groups           sync.Map // map[string]*protocoltypes.Group
-	groupContexts    sync.Map // map[string]*GroupContext
-	groupsSigPubKey  sync.Map // map[string]crypto.PubKey
 	keyStore         *BertySignedKeyStore
 	messageKeystore  *cryptoutil.MessageKeystore
 	deviceKeystore   cryptoutil.DeviceKeystore
 	pubSub           iface.PubSubInterface
-	messageMarshaler *RotationMessageMarshaler
+	rotationInterval *rendezvous.RotationInterval
+	messageMarshaler *OrbitDBMessageMarshaler
+
+	ctx context.Context
+	// FIXME(gfanton): use real map instead of sync.Map
+	groups          *GroupMap           // map[string]*protocoltypes.Group
+	groupContexts   *GroupContextMap    // map[string]*GroupContext
+	groupsSigPubKey *GroupsSigPubKeyMap // map[string]crypto.PubKey
 }
 
 func (s *BertyOrbitDB) registerGroupPrivateKey(g *protocoltypes.Group) error {
@@ -144,25 +159,22 @@ func NewBertyOrbitDB(ctx context.Context, ipfs coreapi.CoreAPI, options *NewOrbi
 	}
 
 	options.applyDefaults()
-	options.Logger = options.Logger.Named("odb")
 
 	ks := &BertySignedKeyStore{}
 	options.Keystore = ks
 	options.Identity = &identityprovider.Identity{}
 
-	if options.PubSub == nil {
-		self, err := ipfs.Key().Self(ctx)
-		if err != nil {
-			return nil, err
-		}
+	self, err := ipfs.Key().Self(ctx)
+	if err != nil {
+		return nil, err
+	}
 
+	if options.PubSub == nil {
 		options.PubSub = pubsubcoreapi.NewPubSub(ipfs, self.ID(), time.Second, options.Logger, options.Tracer)
 	}
 
-	mm := NewRotationMessageMarshaler(options.RotationInterval)
-	// if options.MessageMarshaler == nil {
-	// 	options.MessageMarshaler = mm
-	// }
+	mm := NewOrbitDBMessageMarshaler(self.ID(), options.DeviceKeystore, options.RotationInterval)
+	options.MessageMarshaler = mm
 
 	orbitDB, err := baseorbitdb.NewOrbitDB(ctx, ipfs, &options.NewOrbitDBOptions)
 	if err != nil {
@@ -170,6 +182,7 @@ func NewBertyOrbitDB(ctx context.Context, ipfs coreapi.CoreAPI, options *NewOrbi
 	}
 
 	bertyDB := &BertyOrbitDB{
+		ctx:              ctx,
 		messageMarshaler: mm,
 		BaseOrbitDB:      orbitDB,
 		keyStore:         ks,
@@ -177,6 +190,9 @@ func NewBertyOrbitDB(ctx context.Context, ipfs coreapi.CoreAPI, options *NewOrbi
 		messageKeystore:  options.MessageKeystore,
 		rotationInterval: options.RotationInterval,
 		pubSub:           options.PubSub,
+		groups:           &GroupMap{},
+		groupContexts:    &GroupContextMap{},    // map[string]*GroupContext
+		groupsSigPubKey:  &GroupsSigPubKeyMap{}, // map[string]crypto.PubKey
 	}
 
 	if err := bertyDB.RegisterAccessControllerType(NewSimpleAccessController); err != nil {
@@ -195,7 +211,6 @@ func (s *BertyOrbitDB) openAccountGroup(ctx context.Context, options *orbitdb.Cr
 	if err != nil {
 		return nil, errcode.ErrOrbitDBOpen.Wrap(err)
 	}
-
 	l.Debug("Got AccountPrivKey", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
 
 	skProof, err := s.deviceKeystore.AccountProofPrivKey()
@@ -212,7 +227,7 @@ func (s *BertyOrbitDB) openAccountGroup(ctx context.Context, options *orbitdb.Cr
 
 	l.Debug("Got account group", tyber.FormatStepLogFields(ctx, []tyber.Detail{{Name: "Group", Description: g.String()}})...)
 
-	gc, err := s.OpenGroup(ctx, g, options)
+	gc, err := s.OpenGroup(g, options)
 	if err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
@@ -225,7 +240,7 @@ func (s *BertyOrbitDB) openAccountGroup(ctx context.Context, options *orbitdb.Cr
 
 	l.Debug("Account group context activated", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
 
-	TagGroupContextPeers(ctx, gc, ipfsCoreAPI, 84)
+	TagGroupContextPeers(ctx, l, gc, ipfsCoreAPI, 84)
 
 	l.Debug("TagGroupContextPeers done", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
 
@@ -302,7 +317,7 @@ func (s *BertyOrbitDB) setHeadsForGroup(ctx context.Context, g *protocoltypes.Gr
 	return nil
 }
 
-func (s *BertyOrbitDB) OpenGroup(ctx context.Context, g *protocoltypes.Group, options *orbitdb.CreateDBOptions) (*GroupContext, error) {
+func (s *BertyOrbitDB) OpenGroup(g *protocoltypes.Group, options *orbitdb.CreateDBOptions) (*GroupContext, error) {
 	if s.deviceKeystore == nil || s.messageKeystore == nil {
 		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("db open in naive mode"))
 	}
@@ -324,7 +339,7 @@ func (s *BertyOrbitDB) OpenGroup(ctx context.Context, g *protocoltypes.Group, op
 		return nil, err
 	}
 
-	s.Logger().Debug("OpenGroup", tyber.FormatStepLogFields(ctx, tyber.ZapFieldsToDetails(zap.Any("public key", g.PublicKey), zap.Any("secret", g.Secret), zap.Stringer("type", g.GroupType)))...)
+	s.Logger().Debug("OpenGroup", tyber.FormatStepLogFields(s.ctx, tyber.ZapFieldsToDetails(zap.Any("public key", g.PublicKey), zap.Any("secret", g.Secret), zap.Stringer("type", g.GroupType)))...)
 
 	memberDevice, err := s.deviceKeystore.MemberDeviceForGroup(g)
 	if err != nil {
@@ -335,36 +350,38 @@ func (s *BertyOrbitDB) OpenGroup(ctx context.Context, g *protocoltypes.Group, op
 	if err != nil {
 		mpkb = []byte{}
 	}
-	s.Logger().Debug("Got member device", tyber.FormatStepLogFields(ctx, []tyber.Detail{{Name: "DevicePublicKey", Description: base64.RawURLEncoding.EncodeToString(mpkb)}})...)
+	s.Logger().Debug("Got member device", tyber.FormatStepLogFields(s.ctx, []tyber.Detail{{Name: "DevicePublicKey", Description: base64.RawURLEncoding.EncodeToString(mpkb)}})...)
 
 	// Force secret generation if missing
-	if _, err := s.messageKeystore.GetDeviceSecret(ctx, g, s.deviceKeystore); err != nil {
+	if _, err := s.messageKeystore.GetDeviceSecret(s.ctx, g, s.deviceKeystore); err != nil {
 		return nil, errcode.ErrCryptoKeyGeneration.Wrap(err)
 	}
 
-	s.Logger().Debug("Got device secret", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
+	s.Logger().Debug("Got device secret", tyber.FormatStepLogFields(s.ctx, []tyber.Detail{})...)
 
-	metaImpl, err := s.groupMetadataStore(ctx, g, options)
+	metaImpl, err := s.groupMetadataStore(s.ctx, g, options)
 	if err != nil {
 		return nil, errcode.ErrOrbitDBOpen.Wrap(err)
 	}
+	s.messageMarshaler.RegisterGroup(metaImpl.Address().String(), g)
 
-	s.Logger().Debug("Got metadata store", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
+	s.Logger().Debug("Got metadata store", tyber.FormatStepLogFields(s.ctx, []tyber.Detail{})...)
 
-	messagesImpl, err := s.groupMessageStore(ctx, g, options)
+	messagesImpl, err := s.groupMessageStore(s.ctx, g, options)
 	if err != nil {
 		return nil, errcode.ErrOrbitDBOpen.Wrap(err)
 	}
+	s.messageMarshaler.RegisterGroup(messagesImpl.Address().String(), g)
 
-	s.Logger().Debug("Got message store", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
+	s.Logger().Debug("Got message store", tyber.FormatStepLogFields(s.ctx, []tyber.Detail{})...)
 
 	gc := NewContextGroup(g, metaImpl, messagesImpl, s.messageKeystore, memberDevice, s.Logger())
 
-	s.Logger().Debug("Created group context", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
+	s.Logger().Debug("Created group context", tyber.FormatStepLogFields(s.ctx, []tyber.Detail{})...)
 
 	s.groupContexts.Store(groupID, gc)
 
-	s.Logger().Debug("Stored group context", tyber.FormatStepLogFields(ctx, []tyber.Detail{})...)
+	s.Logger().Debug("Stored group context", tyber.FormatStepLogFields(s.ctx, []tyber.Detail{})...)
 
 	return gc, nil
 }
@@ -410,6 +427,17 @@ func (s *BertyOrbitDB) getGroupContext(id string) (*GroupContext, error) {
 		return nil, errcode.ErrMissingMapKey
 	}
 
+	gc, ok := g.(*GroupContext)
+	if !ok {
+		s.groupContexts.Delete(id)
+		return nil, errors.New("cannot cast object to GroupContext")
+	}
+
+	if gc.IsClosed() {
+		s.groupContexts.Delete(id)
+		return nil, errcode.ErrMissingMapKey
+	}
+
 	return g.(*GroupContext), nil
 }
 
@@ -443,6 +471,8 @@ func (s *BertyOrbitDB) storeForGroup(ctx context.Context, o iface.BaseOrbitDB, g
 		return nil, err
 	}
 
+	s.messageMarshaler.RegisterGroup(addr.String(), g)
+
 	linkKey, err := cryptoutil.GetLinkKeyArray(g)
 	if err != nil {
 		return nil, err
@@ -459,12 +489,17 @@ func (s *BertyOrbitDB) storeForGroup(ctx context.Context, o iface.BaseOrbitDB, g
 		options.IO = cborIO
 
 		l.Debug("opening store: register rotation", zap.String("topic", addr.String()))
+
 		s.messageMarshaler.RegisterSharedKeyForTopic(addr.String(), sk)
 		s.rotationInterval.RegisterRotation(time.Now(), addr.String(), key)
 	}
 
 	options.EventBus = eventbus.NewBus()
-	store, err := o.Open(ctx, name, options)
+
+	// @FIXME(d4ryl00): the given context is not the one of the group but one with
+	// a longer time life because go-orbitdb doesn't close correctly the group
+	// and that can lead of bugs when you close/open the same group.
+	store, err := o.Open(s.ctx, name, options)
 	if err != nil {
 		return nil, errcode.ErrOrbitDBOpen.Wrap(err)
 	}
@@ -541,3 +576,7 @@ func (s *BertyOrbitDB) IsGroupLoaded(groupID string) bool {
 
 	return ok && gc != nil
 }
+
+func (s *BertyOrbitDB) GetDevicePKForPeerID(id peer.ID) (pdg *PeerDeviceGroup, ok bool) {
+	return s.messageMarshaler.GetDevicePKForPeerID(id)
+}
