@@ -52,10 +52,11 @@ func testAddBerty(ctx context.Context, t *testing.T, node ipfsutil.CoreAPIMock,
 	defer testutil.Close(t, odb)
 
 	replicate := false
-	gc, err := odb.OpenGroup(ctx, g, &iface.CreateDBOptions{
+	gc, err := odb.OpenGroup(g, &iface.CreateDBOptions{
 		Replicate: &replicate,
 	})
 	require.NoError(t, err)
+	defer gc.Close()
 
 	defer testutil.Close(t, gc)
 
@@ -89,7 +90,7 @@ func testAddBerty(ctx context.Context, t *testing.T, node ipfsutil.CoreAPIMock,
 	require.NoError(t, err)
 
 	for i := 0; i < amountToAdd; i++ {
-		_, err := gc.MessageStore().AddMessage(ctx, []byte(fmt.Sprintf("%d", i)), nil)
+		_, err := gc.MessageStore().AddMessage(ctx, []byte(fmt.Sprintf("%d", i)))
 		require.NoError(t, err)
 		wg.Done()
 	}
