@@ -84,6 +84,103 @@ func TestScenario_MessageMultiMemberGroup(t *testing.T) {
 	})
 }
 
+func TestScenario_GroupDeviceStatusOnMultiMemberGroup(t *testing.T) {
+	cases := []testCase{
+		{"2 clients/connectAll", 2, bertyprotocol.ConnectAll, testutil.Fast, testutil.Flappy, time.Second * 10},
+		{"3 clients/connectAll", 3, bertyprotocol.ConnectAll, testutil.Fast, testutil.Flappy, time.Second * 10},
+		{"5 clients/connectAll", 5, bertyprotocol.ConnectAll, testutil.Slow, testutil.Flappy, time.Second * 20},
+		{"8 clients/connectAll", 8, bertyprotocol.ConnectAll, testutil.Slow, testutil.Flappy, time.Second * 30},
+		{"10 clients/connectAll", 10, bertyprotocol.ConnectAll, testutil.Slow, testutil.Flappy, time.Second * 40},
+	}
+
+	testingScenario(t, cases, func(ctx context.Context, t *testing.T, tps ...*bertyprotocol.TestingProtocol) {
+		// Create MultiMember Group
+		groupID := createMultiMemberGroup(ctx, t, tps...)
+
+		testGroupDeviceStatus(ctx, t, groupID, tps...)
+	})
+}
+
+func testGroupDeviceStatus(ctx context.Context, t *testing.T, groupID []byte, tps ...*bertyprotocol.TestingProtocol) {
+	ntps := len(tps)
+
+	// Get group device status
+	{
+		testutil.LogTree(t, "Get Group Device Status", 1, true)
+		start := time.Now()
+
+		wg := sync.WaitGroup{}
+		statusReceivedLock := sync.Mutex{}
+		statusReceived := make([]map[string]struct{}, ntps)
+		wg.Add(ntps)
+
+		nSuccess := int64(0)
+		for i := range tps {
+			go func(i int) {
+				tp := tps[i]
+				defer wg.Done()
+
+				statusReceived[i] = map[string]struct{}{}
+
+				ctx, cancel := context.WithCancel(ctx)
+				defer cancel()
+
+				sub, inErr := tp.Client.GroupDeviceStatus(ctx, &protocoltypes.GroupDeviceStatus_Request{
+					GroupPK: groupID,
+				})
+				if inErr != nil {
+					assert.NoError(t, inErr, fmt.Sprintf("error for client %d", i))
+					return
+				}
+
+				for {
+					evt, inErr := sub.Recv()
+					if inErr != nil {
+						if inErr != io.EOF {
+							assert.NoError(t, inErr, fmt.Sprintf("error for client %d", i))
+						}
+
+						break
+					}
+
+					assert.Equal(t, evt.Type, protocoltypes.TypePeerConnected)
+					connected := &protocoltypes.GroupDeviceStatus_Reply_PeerConnected{}
+					err := connected.Unmarshal(evt.Event)
+					assert.NoError(t, err, fmt.Sprintf("Unmarshal error for client %d", i))
+
+					statusReceivedLock.Lock()
+					statusReceived[i][connected.PeerID] = struct{}{}
+					done := len(statusReceived[i]) == ntps-1
+					statusReceivedLock.Unlock()
+
+					if done {
+						atomic.AddInt64(&nSuccess, 1)
+						nSuccess := atomic.LoadInt64(&nSuccess)
+
+						got := fmt.Sprintf("%d/%d", nSuccess, ntps)
+						tps[i].Opts.Logger.Debug("received all group device status", zap.String("ok", got))
+						return
+					}
+				}
+			}(i)
+		}
+
+		wg.Wait()
+
+		statusReceivedLock.Lock()
+		ok := true
+		for i := range statusReceived {
+			if !assert.Equal(t, ntps-1, len(statusReceived[i]), fmt.Sprintf("mismatch for client %d", i)) {
+				ok = false
+			}
+		}
+		require.True(t, ok)
+		statusReceivedLock.Unlock()
+
+		testutil.LogTree(t, "duration: %s", 1, false, time.Since(start))
+	}
+}
+
 //
 //func TestScenario_MessageMultiMemberGroup2(t *testing.T) {
 //	cases := []testCase{
@@ -444,13 +541,11 @@ func TestScenario_ReplicateMessage(t *testing.T) {
 func testingScenario(t *testing.T, tcs []testCase, tf testFunc) {
 	if os.Getenv("WITH_GOLEAK") == "1" {
 		defer goleak.VerifyNone(t,
-			goleak.IgnoreTopFunction("github.com/syndtr/goleveldb/leveldb.(*DB).mpoolDrain"),           // inherited from one of the imports (init)
-			goleak.IgnoreTopFunction("github.com/ipfs/go-log/writer.(*MirrorWriter).logRoutine"),       // inherited from one of the imports (init)
-			goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-connmgr.(*BasicConnMgr).background"), // inherited from github.com/ipfs/go-ipfs/core.NewNode
-			goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),        // inherited from github.com/ipfs/go-ipfs/core.NewNode
-			goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-connmgr.(*decayer).process"),         // inherited from github.com/ipfs/go-ipfs/core.NewNode)
-			goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),                    // inherited from github.com/ipfs/go-ipfs/core.NewNode)
-			goleak.IgnoreTopFunction("github.com/desertbit/timer.timerRoutine"),                        // inherited from github.com/ipfs/go-ipfs/core.NewNode)
+			goleak.IgnoreTopFunction("github.com/syndtr/goleveldb/leveldb.(*DB).mpoolDrain"),     // inherited from one of the imports (init)
+			goleak.IgnoreTopFunction("github.com/ipfs/go-log/writer.(*MirrorWriter).logRoutine"), // inherited from one of the imports (init)
+			goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),  // inherited from github.com/ipfs/kubo/core.NewNode
+			goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),              // inherited from github.com/ipfs/kubo/core.NewNode)
+			goleak.IgnoreTopFunction("github.com/desertbit/timer.timerRoutine"),                  // inherited from github.com/ipfs/kubo/core.NewNode)
 			goleak.IgnoreTopFunction("go.opentelemetry.io/otel/instrumentation/grpctrace.wrapClientStream.func1"),
 			goleak.IgnoreTopFunction("go.opentelemetry.io/otel/instrumentation/grpctrace.StreamClientInterceptor.func1.1"),
 		)
@@ -462,11 +557,15 @@ func testingScenario(t *testing.T, tcs []testCase, tf testFunc) {
 
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
+
 			logger, cleanup := testutil.Logger(t)
 			defer cleanup()
 
+			mn := libp2p_mocknet.New()
+			defer mn.Close()
+
 			opts := bertyprotocol.TestingOpts{
-				Mocknet:     libp2p_mocknet.New(ctx),
+				Mocknet:     mn,
 				Logger:      logger,
 				ConnectFunc: tc.ConnectFunc,
 			}
@@ -491,13 +590,11 @@ func testingScenario(t *testing.T, tcs []testCase, tf testFunc) {
 func testingScenarioNonMocked(t *testing.T, tcs []testCase, tf testFunc) {
 	if os.Getenv("WITH_GOLEAK") == "1" {
 		defer goleak.VerifyNone(t,
-			goleak.IgnoreTopFunction("github.com/syndtr/goleveldb/leveldb.(*DB).mpoolDrain"),           // inherited from one of the imports (init)
-			goleak.IgnoreTopFunction("github.com/ipfs/go-log/writer.(*MirrorWriter).logRoutine"),       // inherited from one of the imports (init)
-			goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-connmgr.(*BasicConnMgr).background"), // inherited from github.com/ipfs/go-ipfs/core.NewNode
-			goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),        // inherited from github.com/ipfs/go-ipfs/core.NewNode
-			goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-connmgr.(*decayer).process"),         // inherited from github.com/ipfs/go-ipfs/core.NewNode)
-			goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),                    // inherited from github.com/ipfs/go-ipfs/core.NewNode)
-			goleak.IgnoreTopFunction("github.com/desertbit/timer.timerRoutine"),                        // inherited from github.com/ipfs/go-ipfs/core.NewNode)
+			goleak.IgnoreTopFunction("github.com/syndtr/goleveldb/leveldb.(*DB).mpoolDrain"),     // inherited from one of the imports (init)
+			goleak.IgnoreTopFunction("github.com/ipfs/go-log/writer.(*MirrorWriter).logRoutine"), // inherited from one of the imports (init)
+			goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),  // inherited from github.com/ipfs/kubo/core.NewNode
+			goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),              // inherited from github.com/ipfs/kubo/core.NewNode)
+			goleak.IgnoreTopFunction("github.com/desertbit/timer.timerRoutine"),                  // inherited from github.com/ipfs/kubo/core.NewNode)
 			goleak.IgnoreTopFunction("go.opentelemetry.io/otel/instrumentation/grpctrace.wrapClientStream.func1"),
 			goleak.IgnoreTopFunction("go.opentelemetry.io/otel/instrumentation/grpctrace.StreamClientInterceptor.func1.1"),
 		)
@@ -509,11 +606,15 @@ func testingScenarioNonMocked(t *testing.T, tcs []testCase, tf testFunc) {
 
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
+
 			logger, cleanup := testutil.Logger(t)
 			defer cleanup()
 
+			mn := libp2p_mocknet.New()
+			defer mn.Close()
+
 			opts := bertyprotocol.TestingOpts{
-				Mocknet:     libp2p_mocknet.New(ctx),
+				Mocknet:     mn,
 				Logger:      logger,
 				ConnectFunc: tc.ConnectFunc,
 			}
@@ -868,6 +969,16 @@ func addAsContact(ctx context.Context, t *testing.T, senders, receivers []*berty
 	testutil.LogTree(t, "duration: %s", 0, false, time.Since(start))
 }
 
+func getContactGroup(ctx context.Context, t *testing.T, source *bertyprotocol.TestingProtocol, contact *bertyprotocol.TestingProtocol) *protocoltypes.GroupInfo_Reply {
+	// Get contact group
+	contactGroup, err := source.Client.GroupInfo(ctx, &protocoltypes.GroupInfo_Request{
+		ContactPK: getAccountPubKey(t, contact),
+	})
+	require.NoError(t, err)
+	require.NotNil(t, contactGroup)
+	return contactGroup
+}
+
 func sendMessageToContact(ctx context.Context, t *testing.T, messages []string, tps []*bertyprotocol.TestingProtocol) {
 	for _, sender := range tps {
 		for _, receiver := range tps {
@@ -877,11 +988,7 @@ func sendMessageToContact(ctx context.Context, t *testing.T, messages []string,
 			}
 
 			// Get contact group
-			contactGroup, err := sender.Client.GroupInfo(ctx, &protocoltypes.GroupInfo_Request{
-				ContactPK: getAccountPubKey(t, receiver),
-			})
-			require.NoError(t, err)
-			require.NotNil(t, contactGroup)
+			contactGroup := getContactGroup(ctx, t, sender, receiver)
 
 			// Send messages on contact group
 			sendMessageOnGroup(ctx, t, []*bertyprotocol.TestingProtocol{sender}, []*bertyprotocol.TestingProtocol{receiver}, contactGroup.Group.PublicKey, messages)
