@@ -11,7 +11,7 @@ import (
 
 	datastore "github.com/ipfs/go-datastore"
 	ds_sync "github.com/ipfs/go-datastore/sync"
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
 	libp2p_mocknet "github.com/libp2p/go-libp2p/p2p/net/mock"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -170,7 +170,7 @@ func testMemberStore(t *testing.T, memberCount, deviceCount int) {
 func ipfsAPIUsingMockNet(ctx context.Context, t *testing.T) (ipfsutil.ExtendedCoreAPI, func()) {
 	ipfsopts := &ipfsutil.TestingAPIOpts{
 		Logger:    zap.NewNop(),
-		Mocknet:   libp2p_mocknet.New(ctx),
+		Mocknet:   libp2p_mocknet.New(),
 		Datastore: ds_sync.MutexWrap(datastore.NewMapDatastore()),
 	}
 
@@ -532,8 +532,9 @@ func TestMetadataAliasLifecycle(t *testing.T) {
 	g, err := cryptoutil.GetGroupForContact(sk)
 	require.NoError(t, err)
 
-	cg0, err := peers[0].DB.OpenGroup(ctx, g, nil)
+	cg0, err := peers[0].DB.OpenGroup(g, nil)
 	require.NoError(t, err)
+	defer cg0.Close()
 
 	require.False(t, cg0.MetadataStore().Index().(*metadataStoreIndex).ownAliasKeySent)
 
@@ -552,8 +553,9 @@ func TestMetadataAliasLifecycle(t *testing.T) {
 	g, err = cryptoutil.GetGroupForContact(sk)
 	require.NoError(t, err)
 
-	cg1, err := peers[1].DB.OpenGroup(ctx, g, nil)
+	cg1, err := peers[1].DB.OpenGroup(g, nil)
 	require.NoError(t, err)
+	defer cg1.Close()
 
 	_ = cg1
 
