@@ -3,7 +3,7 @@ import { View } from 'react-native'
 
 import Logo from '@berty/assets/logo/1_berty_picto.svg'
 import { useStyles } from '@berty/contexts/styles'
-import { useThemeColor } from '@berty/store/hooks'
+import { useThemeColor } from '@berty/hooks'
 
 export const useStylesNotification = () => {
 	const { flex } = useStyles()
